@@ -20,6 +20,7 @@ use base 'WebGUI::Asset::Sku';
 use JSON;
 use WebGUI::HTMLForm;
 use WebGUI::International;
+use WebGUI::Shop::Admin;
 use WebGUI::Shop::AddressBook;
 use WebGUI::Utility;
 
@@ -212,6 +213,28 @@ sub getMaxAllowedInCart {
 	return 1;
 }
 
+#----------------------------------------------------------------------------
+
+=head2 getPostPurchaseActions ( item )
+
+Return a hash reference of "label" => "url" to do things with this item after
+it is purchased. C<item> is the WebGUI::Shop::TransactionItem for this item
+
+=cut
+
+sub getPostPurchaseActions {
+    my ( $self, $item ) = @_;
+    my $session  = $self->session;
+    my $opts     = $self->SUPER::getPostPurchaseActions();
+    if($self->getParent->isRegistrationStaff) {
+        my $i18n     = WebGUI::International->new( $session, "Asset_EventManagementSystem" );
+        my $badgeId = $item->get('options')->{badgeId};
+
+        $opts->{ $i18n->get('print') } = $self->getParent->getUrl( "func=printBadge;badgeId=$badgeId" );
+    }
+    return $opts;
+}
+
 #-------------------------------------------------------------------
 
 =head2 getPrice
@@ -404,11 +427,19 @@ sub view {
                         ;
 	
     # instanciate address
-    my $address = WebGUI::Shop::AddressBook->newByUserId($self->session)->getAddress($form->get("addressId")) if ($form->get("addressId"));
+    my $address      = undef;
+    my $address_book = WebGUI::Shop::AddressBook->newByUserId($self->session);
+    if ($form->get("addressId")) {
+        $address = $address_book->getAddress($form->get("addressId"));
+    }
+    else {
+        $address = eval{ $address_book->getDefaultAddress }
+    }
 
     # build the form that the user needs to fill out with badge holder information
     $vars{formHeader} = WebGUI::Form::formHeader($session, {action => $self->getUrl})
-                      . WebGUI::Form::hidden($session, {name=>"func", value =>'addToCart'});
+                      . WebGUI::Form::hidden($session, {name=>"func", value =>'addToCart'})
+                      . WebGUI::Form::hidden($session, {name=>"addressId", value=>(defined $address ? $address->getId : "" )});;
     $vars{formFooter} = WebGUI::Form::formFooter($session);
     $vars{name}       = WebGUI::Form::text($session, {
                             name         => 'name',
@@ -457,9 +488,20 @@ sub view {
     if($self->getQuantityAvailable() > 0){ 
         $vars{submitAddress} = WebGUI::Form::submit($session, {value => $i18n->get('add to cart'),});
     }
+    $vars{resetButton}  = q{<input type="button" value="}.$i18n->get('clear form'). q{" onclick="WebGUI.Form.clearForm(this.form)" />};
     $vars{title}       = $self->getTitle;
     $vars{description} = $self->get('description');
-	
+    $vars{search_url  } = $self->getUrl("shop=address;method=ajaxSearch");
+
+    my $shopAdmin       = WebGUI::Shop::Admin->new($session);
+    my $isStaff         = $self->getParent->isRegistrationStaff;
+    my $canManageShop   = $shopAdmin->canManage;
+    my $isCashier       = $shopAdmin->isCashier;
+
+    if($isStaff && ($canManageShop || $isCashier)) {
+        $vars{canSearch}     = 1;
+	}
+
     # render the page;
     return $self->processTemplate(\%vars, undef, $self->{_viewTemplate});
 }
@@ -495,13 +537,46 @@ sub www_addToCart {
 	if ($badgeInfo{name} eq "") {
 		$error =  sprintf $i18n->get('is required'), $i18n->get('name','Shop');
 	}
-	
+
 	# return them back to the previous screen if they messed up
 	if ($error) {
 		$self->{_errorMessage} = $error;
 		return $self->www_view($error);
 	}
-	
+
+    #check to see if address has changed - if so, create a new address and set it to the default
+    my $address_id = $form->get("addressId");
+    if($address_id) {
+        my $address      = undef;
+        my $address_book = WebGUI::Shop::AddressBook->newByUserId($self->session);
+        $address = $address_book->getAddress($address_id);
+        my $has_changes = 0;
+        my $new_address  = {};
+        foreach my $field_name (qw/name address1 address2 address3 city state country code phoneNumber organization email/) {
+            my $form_field_name = $field_name;
+            $form_field_name = "zipcode" if ($field_name eq "code");
+            if($field_name eq "name") {
+                if($address->get('firstName')." ".$address->get('lastName') ne $badgeInfo{name}) {
+                    $has_changes = 1;
+                }
+                ($new_address->{firstName},$new_address->{lastName}) = split(" ",$badgeInfo{name});
+                next;
+            }
+            elsif($address->get($field_name) ne $badgeInfo{$form_field_name}) {
+                $has_changes = 1;
+            }
+            $new_address->{$field_name} = $badgeInfo{$form_field_name};
+        }
+
+        if($has_changes) {
+            my $address_book = WebGUI::Shop::AddressBook->newByUserId($self->session);
+            $new_address->{label} = $form->get("label")." New";
+            my $new_address = $address_book->addAddress($new_address);
+            $address_book->update({defaultAddressId => $new_address->getId });
+        }
+
+    }
+
 	# add it to the cart
 	$self->addToCart(\%badgeInfo);
 	return $self->getParent->www_buildBadge($self->getOptions->{badgeId});
