@@ -23,7 +23,7 @@ use WebGUI::Form;
 use WebGUI::Exception;
 use List::MoreUtils qw{ any };
 use Tie::IxHash;
-use Clone qw/clone/;
+use Storable qw/dclone/;
 use HTML::Packer;
 use JSON qw{ to_json from_json };
 use Try::Tiny;
@@ -687,14 +687,18 @@ sub process {
 
     if ($self->get('state') =~ /^trash/) {
         my $i18n = WebGUI::International->new($session, 'Asset_Template');
+        my $url  = $session->asset ? $session->asset->get('url')  ##Called via asset
+                                   : $session->url->getRaw();     ##Called via operation, like auth
         $session->errorHandler->warn('process called on template in trash: '.$self->getId
-            .'. The template was called through this url: '.$session->asset->get('url'));
+            .". The template was called through this url: $url");
         return $session->var->isAdminOn ? $i18n->get('template in trash') : '';
     }
     elsif ($self->get('state') =~ /^clipboard/) {
         my $i18n = WebGUI::International->new($session, 'Asset_Template');
+        my $url  = $session->asset ? $session->asset->get('url')
+                                   : $session->url->getRaw();
         $session->errorHandler->warn('process called on template in clipboard: '.$self->getId
-            .'. The template was called through this url: '.$session->asset->get('url'));
+            .". The template was called through this url: $url");
         return $session->var->isAdminOn ? $i18n->get('template in clipboard') : '';
     }
 
@@ -910,8 +914,8 @@ on this being here.
 
 sub update {
     my $self = shift;
-    my $requestedProperties = shift;
-    my $properties = clone($requestedProperties);
+    my $requestedProperties = shift || {};
+    my $properties = dclone($requestedProperties);
 
     if (exists $properties->{headBlock}) {
         $properties->{extraHeadTags} .= $properties->{headBlock};
