@@ -544,12 +544,6 @@ sub www_view {
 	$self->session->http->setLastModified($self->getContentLastModified);
 	$self->session->http->sendHeader;
     ##Have to dupe this code here because Wobject does not call SUPER.
-    if ($self->get('synopsis')) {
-        $self->session->style->setMeta({
-                name    => 'Description',
-                content => $self->get('synopsis'),
-        });
-    }
 	$self->prepareView;
 	my $style = $self->processStyle($self->getSeparator, { noHeadTags => 1 });
 	my ($head, $foot) = split($self->getSeparator,$style);
