@@ -150,6 +150,23 @@ sub addRevision {
             );
         }
     }
+
+    # Copy metadata values
+    my $db    = $self->session->db;
+    my $id    = $self->getId;
+    my $then  = $self->get('revisionDate');
+    my $mdget = q{
+        select fieldId, value from metaData_values
+        where assetId = ? and revisionDate = ?
+    };
+    my $mdset = q{
+        insert into metaData_values (fieldId, value, assetId, revisionDate)
+        values (?, ?, ?, ?)
+    };
+    for my $row (@{ $db->buildArrayRefOfHashRefs($mdget, [ $id, $then ]) }) {
+        $db->write($mdset, [ $row->{fieldId}, $row->{value}, $id, $now ]);
+    }
+
     $self->session->db->commit;
 	
 	# merge the defaults, current values, and the user set properties
@@ -371,12 +388,16 @@ sub purgeRevision {
 	if ($self->getRevisionCount > 1) {
 		$self->session->db->beginTransaction;
         	foreach my $definition (@{$self->definition($self->session)}) {
-			$self->session->db->write("delete from ".$definition->{tableName}." where assetId=? and revisionDate=?",[$self->getId, $self->get("revisionDate")]);
+			$self->session->db->write("delete from ".$self->session->db->dbh->quote_identifier($definition->{tableName})." where assetId=? and revisionDate=?",[$self->getId, $self->get("revisionDate")]);
         	}
 		my ($count) = $self->session->db->quickArray("select count(*) from assetData where assetId=? and status='pending'",[$self->getId]);
 		if ($count < 1) {
 			$self->session->db->write("update asset set isLockedBy=null where assetId=?",[$self->getId]);
 		}
+		$self->session->db->write(
+			'delete from metaData_values where assetId=?  and revisionDate=?',
+			[ $self->getId, $self->get('revisionDate') ]
+		);
         	$self->session->db->commit;
 		$self->purgeCache;
 		$self->updateHistory("purged revision ".$self->get("revisionDate"));
