@@ -278,6 +278,7 @@ sub finish {
         $props{latch}  = 0;
     }
     $props{endTime} = time();
+    $props{redirect} = $self->{redirect};
     $self->set( \%props );
 }
 
@@ -514,6 +515,20 @@ sub setGroup {
 
 #-----------------------------------------------------------------
 
+=head2 setRedirect($url)
+
+Allows a redirect to be set for the process after the initial fork.  This happens
+in the case when a file is to be downloaded after the fork finishes.
+
+=cut
+
+sub setRedirect {
+    my ( $self, $url ) = @_;
+    $self->{redirect} = $url;
+}
+
+#-----------------------------------------------------------------
+
 =head2 request ($module, $subname, $data)
 
 Internal method. Generates a hashref suitable for passing to runRequest.
