@@ -19,13 +19,24 @@ our $HELP = {
 		fields => [	
 		],
 		variables => [
-			{	name => "shelves" , required=>1},
+			{	name => "shelves" , required=>1, variables => [
+					{ name => "title",
+                      description => 'shelf_title', },
+					{ name => "url",
+                      description => 'shelf_url', },
+                ],
+            },
 			{	name => "products" , required=>1, variables => [
+					{ name => "url",
+                      description => 'product_url', },
 					{ name => "thumbnailUrl" },
 					{ name => "price" },
+					{ name => "addToCartForm" },
 					],
 				},
 			{	name => "templateId", description=>"shelf template help" },
+			{	name => "noViewableSkus", },
+			{	name => "emptyShelf",      },
 		],
 		related => [  
 		],
