@@ -64,7 +64,7 @@ use Apache2::FilterRec;
 use Apache2::RequestIO;
 use Apache2::RequestRec;
 use ModPerl::Util;
-use Net::Subnets;
+use Net::CIDR::Lite;
 
 my @subTimes = ();
 my $depth = 0;
@@ -126,6 +126,16 @@ Handler that adds the results to the body of the outgoing page.
 sub output {
 	my $f = shift;
 	return Apache2::Const::DECLINED unless($f->r->content_type =~ 'text/html');
+    my $server = Apache2::ServerUtil->server;
+    my $sn = $server->dir_config('ProfileSubnet');
+    if ($sn) {
+        my $conn = $f->c;
+        my $ipAddress = $conn->remote_ip;
+        my $net = Net::CIDR::Lite->new($sn);
+        if (!$net->find($ipAddress)) {
+            return Apache2::Const::DECLINED;
+        }
+    }
 	while($f->read(my $buffer, 1024)) {
 		my $content .= $buffer;
 		if ($content =~ /(<\/body)/i) {
