@@ -15,6 +15,7 @@ package WebGUI::SQL;
 =cut
 
 use strict;
+use Scalar::Util qw( weaken );
 use DBI;
 use Tie::IxHash;
 use WebGUI::SQL::ResultSet;
@@ -445,7 +446,9 @@ sub connect {
         $dbh->{$paramName} = $paramValue;
     }
 
-	bless {_dbh=>$dbh, _session=>$session}, $class;
+	my $self = bless {_dbh=>$dbh, _session=>$session}, $class;
+        weaken( $self->{_session} );
+        return $self;
 }
 
 #-------------------------------------------------------------------
@@ -676,7 +679,7 @@ sub quickCSV {
 	my $params = shift;
 	my ($sth, $output, @data);
 
-	my $csv = Text::CSV_XS->new({ eol => "\n" });
+	my $csv = Text::CSV_XS->new({ eol => "\n", binary => 1 });
 
 	$sth = $self->prepare($sql);
 	$sth->execute($params);
@@ -685,7 +688,10 @@ sub quickCSV {
 	$output = $csv->string();
 
 	while (@data = $sth->array) {
-		return undef unless $csv->combine(@data);
+		if ( ! $csv->combine(@data) ) {
+                    $self->session->log->error( "Problem creating CSV row: " . $csv->error_diag );
+                    return undef;
+                }
 		$output .= $csv->string();
 	}
 
