@@ -221,6 +221,10 @@ our $I18N = {
     'lastUpdated' => '1152808882',
     'message' => 'Een onderdeel van een reactieformulier dat moderators in staat stelt de grootte van individuele threads te bepalen. Dit kan alleen bij threads.'
   },
+  'keywords.form' => {
+    'lastUpdated' => '1346179964',
+    'message' => 'Een tekst-invoerveld om zoekwoorden in te voeren. '
+  },
   'lock.form' => {
     'lastUpdated' => '1152808933',
     'message' => 'Een ja/nee-knop om de thread af te sluiten, zodat berichten niet kunnen worden toegevoegd noch bewerkt '
