@@ -321,6 +321,12 @@ our $I18N = {
         lastUpdated => 0,
     },
 
+    'photoHeight' => {
+        message => q|The height used to display photos.|,
+        context => q|Template variable.|,
+        lastUpdated => 0,
+    },
+
     'photo width' => {
         message => q|Photo width|,
         context => q|Label in the edit screen|,
@@ -333,6 +339,18 @@ our $I18N = {
         lastUpdated => 0,
     },
 
+    'photo height' => {
+        message => q|Photo Height|,
+        context => q|Label in the edit screen|,
+        lastUpdated => 0,
+    },
+
+    'photo height help' => {
+        message => q|Slides in the photo carousel have to have a fixed height to render in some browsers.  To disable this feature, set it to 0.|,
+        context => q|hoverhelp for photoHeight in the edit screen|,
+        lastUpdated => 0,
+    },
+
     'sortAlphabeticallyChronologically' => {
         message => q|Sort Order|,
         context => q|Label in the edit screen|,
