@@ -15,6 +15,38 @@ our $I18N = {
 		message => q|Take Survey|,
 		lastUpdated => 1224686319
 	},
+	'visualize' => {
+		message => q|Visualize|,
+		lastUpdated => 0
+	},
+	'generate' => {
+		message => q|Generate|,
+		lastUpdated => 0
+	},
+	'survey visualization' => {
+		message => q|Survey Visualization|,
+		lastUpdated => 0
+	},
+	'visualization success' => {
+		message => q|Visualization successfully generated to|,
+		lastUpdated => 0
+	},
+	'visualization format' => {
+		message => q|Visualisation Format|,
+		lastUpdated => 0
+	},
+	'visualization format help' => {
+		message => q|Choose the type of visualization file you want to generate|,
+		lastUpdated => 0
+	},
+	'visualization layout algorithm' => {
+		message => q|Visualisation Layout Algorithm|,
+		lastUpdated => 0
+	},
+	'visualization layout algorithm help' => {
+		message => q|Choose the GraphViz layout algorithm you want to use|,
+		lastUpdated => 0
+	},
 	'view simple results' => {
 		message => q|View Simple Results|,
 		lastUpdated => 1224686319
@@ -31,10 +63,22 @@ our $I18N = {
 		message => q|View Grade Book|,
 		lastUpdated => 1224686319
 	},
+    'delete responses' => {
+        message => q|Delete Responses|,
+        lastUpdated => 0
+    },
 	'continue button' => {
 		message => q|Continue|,
 		lastUpdated => 1224686319
 	},
+    'logical section' => {
+		message => q|Logical Section|,
+		lastUpdated => 1224686319
+    },
+    'logical section help' => {
+		message => q|A logical section, or its questions, are never shown.  They are used to silently execute jump commands.|,
+		lastUpdated => 1224686319
+    },
 	'add section' => {
 		message => q|Add Section|,
 		lastUpdated => 1224686319
@@ -63,6 +107,10 @@ our $I18N = {
 		message => q|Delete|,
 		lastUpdated => 1224686319
 	},
+	'warnings' => {
+        message => q|Warnings|,
+        lastUpdated => 0
+    },
 	'section number' => {
 		message => q|Section Number:|,
 		lastUpdated => 1224686319
@@ -77,13 +125,13 @@ our $I18N = {
 		lastUpdated => 1224686319
 	},
     'questions on section page description' => {
-        message => q|Are question displayed on the initial page of this section or on the next page.|,
+        message => q|Whether questions are displayed on the initial page of this section or on the next page.|,
         context => q|Description of the 'questions on section page' field, used as hoverhelp in the edit section dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1249057316
     },
 
 	'section name' => {
-		message => q|Section name:|,
+		message => q|Section title:|,
 		lastUpdated => 1224686319
 	},
     'section name description' => {
@@ -101,7 +149,7 @@ our $I18N = {
         lastUpdated => 0 
     },
 	'section custom variable name' => {
-		message => q|Section custom variable name:|,
+		message => q|Section variable name:|,
 		lastUpdated => 1224686319
 	},
     'section custom variable name description' => {
@@ -110,7 +158,7 @@ our $I18N = {
         lastUpdated => 0
     },
 	'section branch goto variable name' => {
-		message => q|Section branch goto variable name:|,
+		message => q|Jump to:|,
 		lastUpdated => 1224686319
 	},
     'section branch goto variable name description' => {
@@ -222,6 +270,10 @@ our $I18N = {
 		message => q|Question type:|,
 		lastUpdated => 1224686319
 	},
+	'randomized words' => {
+		message => q|Randomized words:|,
+		lastUpdated => 1224686319
+	},
     'question type description' => {
         message => q|Select this question's field type.|,
         context => q|Description of the 'question type' field, used as hoverhelp in the edit question dialog.|,
@@ -243,9 +295,9 @@ our $I18N = {
 		lastUpdated => 1224686319
 	},
     'show text in button description' => {
-        message => q|Select if the buttons of a multiple choice question display the answer values or not.|,
+        message => q|By default multiple choice answer buttons show the answer text above each button. Change this to have the text appear inside of the buttons.|,
         context => q|Description of the 'show text in button' field, used as hoverhelp in the edit question dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1239251986
     },
 	'allow comment' => {
 		message => q|Allow comment:|,
@@ -256,94 +308,103 @@ our $I18N = {
         context => q|Description of the 'allow comment' field, used as hoverhelp in the edit question dialog.|,
         lastUpdated => 0
     },
-	'cols' => {
-		message => q|Cols:|,
+	'comment cols' => {
+		message => q|Comment Cols:|,
 		lastUpdated => 1224686319
 	},
     'cols description' => {
-        message => q|The number of columns of the textarea input.|,
+        message => q|The number of columns used for the input field (for TextArea question types).|,
         context => q|Description of the 'cols' field, used as hoverhelp in the edit question dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1241588599
+    },
+    'comment rows' => {
+            message => q|Comment Rows:|,
+            lastUpdated => 1224686319
     },
-	'rows' => {
-		message => q|Rows:|,
-		lastUpdated => 1224686319
-	},
     'rows description' => {
-        message => q|The number of rows of the textarea input.|,
+        message => q|The number of rows used for the input field (for TextArea question types).|,
         context => q|Description of the 'rows' field, used as hoverhelp in the edit question dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1241588599
+    },
+    'maximum number of answers' => {
+            message => q|Maximum number of answers:|,
+            lastUpdated => 1224686319
     },
-	'maximum number of answers' => {
-		message => q|Maximum number of answers:|,
-		lastUpdated => 1224686319
-	},
     'maximum number of answers description' => {
-        message => q|Enter the maximum number of answers.|,
+        message => q|For multi-choice questions, how many answers the user can select. <br>0 = unlimited.<br>1 = radio group style.<br>2 and above = checkbox style.|,
         context => q|Description of the 'maximum number of answers' field, used as hoverhelp in the edit question dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1241764603,
+    },
+    'required label' => {
+            message => q|Required|,
+            lastUpdated => 1224686319
     },
-	'required label' => {
-		message => q|Required|,
-		lastUpdated => 1224686319
-	},
     'required description' => {
         message => q|Is this a required question?|,
         context => q|Description of the 'required' field, used as hoverhelp in the edit question dialog.|,
         lastUpdated => 0
     },
-	'question value' => {
-		message => q|Question value:|,
-		lastUpdated => 1224686319
-	},
-    'question value description' => {
-        message => q|Enter a value for this question.|,
+    'question score' => {
+            message => q|Question score:|,
+            lastUpdated => 1224686319
+    },
+    'question score description' => {
+        message => q|Default score to use for answers in this question that don't have an answer score value set.|,
         context => q|Description of the 'question value' field, used as hoverhelp in the edit question dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1239255403
+    },
+    'please enter answer information' => {
+            message => q|Please enter answer information:|,
+    context => q|Title of the edit answer dialog.|,
+            lastUpdated => 1224686319
+    },
+    'answer number' => {
+            message => q|Answer number:|,
+            lastUpdated => 1224686319
     },
-	'please enter answer information' => {
-		message => q|Please enter answer information:|,
-        context => q|Title of the edit answer dialog.|,
-		lastUpdated => 1224686319
-	},
-	'answer number' => {
-		message => q|Answer number:|,
-		lastUpdated => 1224686319
-	},
     'answer number description' => {
         message => q|The number of this answer|,
         context => q|Description of the 'answer number' field, used as hoverhelp in the edit answer dialog.|,
         lastUpdated => 0
     },
-	'answer text' => {
-		message => q|Answer text:|,
-		lastUpdated => 1224686319
-	},
+    'answer text' => {
+            message => q|Answer text:|,
+            lastUpdated => 1224686319
+    },
     'answer text description' => {
         message => q|Enter a text for this answer. For multiple choice questions this answer will be displayed above the buttons.|,
         context => q|Description of the 'answer text' field, used as hoverhelp in the edit answer dialog.|,
         lastUpdated => 0
     },
-	'recorded answer' => {
-		message => q|Recorded answer:|,
-		lastUpdated => 1224686319
-	},
+    'recorded answer' => {
+            message => q|Recorded Answer:|,
+            lastUpdated => 1224686319
+    },
     'recorded answer description' => {
-        message => q|The answer that will be recorded in the database. The recorded answer will be displayed in a multiple choice question's buttons, only if the question's 'Show text in button' property is set to yes. Otherwise the multiple choice buttons will be empty. |,
+        message => q|Determines what gets recorded as the response value if this answer is selected. Allows you to 'recode' recorded responses, e.g. 'Yes' could be recorded as '1' and 'No' as '0'. Relevant only for Multiple Choice questions (other question types record the input actually entered by the user: free text, selected date, etc..).|,
         context => q|Description of the 'recorded answer' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
+        lastUpdated => 1239251436
+    },
+    'jump to' => {
+            message => q|Jump to:|,
+            lastUpdated => 1224686319
+    },
+    'jump expression' => {
+            message => q|Jump expression:|,
+            lastUpdated => 1229318805
     },
-	'jump to' => {
-		message => q|Jump to:|,
-		lastUpdated => 1224686319
-	},
     'jump to description' => {
         message => q|The section or question with this variable name will be the next to be displayed after this answer.|,
         context => q|Description of the 'jump to' field, used as hoverhelp in the edit answer dialog.|,
         lastUpdated => 0
+    },
+    'jump expression description' => {
+        message => q|An expression used to control complex branching based user responses to previous questions. Ignored unless enableSurveyExpressionEngine enabled in your site config file.|,
+        context => q|Description of the 'jump expression' field, used as hoverhelp in the edit answer dialog.|,
+        lastUpdated => 1239259550
     },
 	'text answer' => {
-		message => q|Text answer|,
+		message => q|TextArea|,
 		lastUpdated => 1224686319
 	},
 	'is this the correct answer' => {
@@ -351,7 +412,7 @@ our $I18N = {
 		lastUpdated => 1224686319
 	},
     'is this the correct answer description' => {
-        message => q|Select wether this is the correct answer or not.|,
+        message => q|Select whether this is the correct answer or not.|,
         context => q|Description of the 'is this the correct answer' field, used as hoverhelp in the edit answer dialog.|,
         lastUpdated => 0
     },
@@ -363,50 +424,50 @@ our $I18N = {
 		message => q|No|,
 		lastUpdated => 1224686319
 	},
-	'min' => {
+	'min label' => {
 		message => q|Min|,
-		lastUpdated => 1224686319
+		lastUpdated => 1241588065
 	},
-    'min description' => {
-        message => q|Set the min value of this answer for slider type questions.|,
-        context => q|Description of the 'min' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
-    },
+        'min description' => {
+            message => q|The minimum numeric value allowed for this answer (for numeric question types such as Number and Slider). Keep this field empty if you do not want to enforce a minimum value. |,
+            context => q|Description of the 'min' field, used as hoverhelp in the edit answer dialog.|,
+            lastUpdated => 1241588065
+        },
 	'max label' => {
 		message => q|Max|,
-		lastUpdated => 1224686319
+		lastUpdated => 1241588065
 	},
-    'max description' => {
-        message => q|Set the max value of this answer for slider type questions.|,
-        context => q|Description of the 'max' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
-    },
+        'max description' => {
+            message => q|The maximum numeric value allowed for this answer (for Number and Slider type questions). Keep this field empty if you do not want to enforce a maximum value. |,
+            context => q|Description of the 'max' field, used as hoverhelp in the edit answer dialog.|,
+            lastUpdated => 1241588065
+        },
 	'step label' => {
 		message => q|Step|,
-		lastUpdated => 1224686319
+		lastUpdated => 1241588065
 	},
-    'step description' => {
-        message => q|Set the step value of this answer for slider type questions.|,
-        context => q|Description of the 'step' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
-    },
+        'step description' => {
+            message => q|The step value, that is, the numeric interval to allow between values (for Number and Slider type questions).  Keep this field empty if you do not want to enforce a step value. |,
+            context => q|Description of the 'step' field, used as hoverhelp in the edit answer dialog.|,
+            lastUpdated => 0
+        },
 	'verbatim label' => {
 		message => q|Verbatim|,
 		lastUpdated => 1224686319
 	},
-    'verbatim description' => {
-        message => q|Set to yes to add an extra text input to the answer, where the user can enter a single line of text.|,
-        context => q|Description of the 'verbatim' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
-    },
-	'answer value' => {
-		message => q|Answer value:|,
-		lastUpdated => 1224686319
+        'verbatim description' => {
+            message => q|Set to yes to add an extra text input to the answer, where the user can enter a single line of text. Typically used to permit a free-text 'other' response.|,
+            context => q|Description of the 'verbatim' field, used as hoverhelp in the edit answer dialog.|,
+            lastUpdated => 0
+        },
+	'answer score' => {
+		message => q|Answer score:|,
+		lastUpdated => 1239251986
 	},
-    'answer value description' => {
-        message => q|Enter a value for this answer.|,
-        context => q|Description of the 'answer value' field, used as hoverhelp in the edit answer dialog.|,
-        lastUpdated => 0
+    'answer score description' => {
+        message => q|Assign a numeric score to this answer. If blank, the question score value will used instead. Used in question scoring and jump expressions.|,
+        context => q|Description of the 'answer score' field, used as hoverhelp in the edit answer dialog.|,
+        lastUpdated => 1239251986
     },
 	'checked' => {
 		message => q|Checked|,
@@ -430,6 +491,53 @@ our $I18N = {
         lastUpdated => 0,
     },
 
+    'Feedback Template' => {
+        message     => q|Feedback Template|,
+        lastUpdated => 0,
+    },
+
+    'Feedback Template help' => {
+        message     => q|The template used to display response feedback.|,
+        lastUpdated => 0,
+    },
+
+    'do after timelimit label' => {
+        message => q|Do After Time Limit:|,
+        lastUpdated => 1224686319,
+        context => q|label for the 'do after timelimit' field on the Properties tab of the Survey's edit screen.|,
+    },
+    'do after timelimit hoverHelp' => {
+        message => q|Select what happens after the time limit for finishing the survey has expired.|,
+        lastUpdated => 1231193335,
+        context => q|description of the 'do after timelimit' field on the Properties tab of the Survey's edit
+screen|,
+    }, 
+    'exit url label' =>{
+        message => q|Exit URL|,
+        lastUpdated => 0,
+        context => q|Label for the 'exit url' option of the 'do after timelimit' field on the Properties tab of the
+Survey's edit screen|,
+    },
+    'restart survey label' =>{
+        message => q|Restart Survey|,
+        lastUpdated => 0,
+        context => q|Label for the 'restart survey' option of the 'do after timelimit' field on the Properties tab of the
+Survey's edit screen|,
+    },
+    'restart message' =>{
+        message => q|The survey was restarted because the time limit for completing the survey was reached.|,
+        lastUpdated => 0,
+        context => q|The message shown to the user taking the survey when the survey is restarted after reaching
+the time limit for completing the survey. This message is in the 'take survey' template.|,
+    },
+    'Quiz mode summaries' => {
+        message     => q|Show quiz mode summaries?|,
+        lastUpdated => 0,
+    },
+    'Quiz mode summaries help' => {
+        message     => q|When set, summaries are shown to users giving their quiz results.|,
+        lastUpdated => 0,
+    },
     'Show user their progress' => {
         message     => q|Show user their progress?|,
         lastUpdated => 0,
@@ -490,6 +598,46 @@ our $I18N = {
         lastUpdated => 1241648155,
     },
 
+    'Overview Report Template' => {
+        message     => q|Overview Report Template|,
+        lastUpdated => 0,
+    },
+
+    'Overview Report Template help' => {
+        message     => q|The template used to display the Overview Report.|,
+        lastUpdated => 0,
+    },
+
+    'Gradebook Report Template' => {
+        message     => q|Gradebook Report Template|,
+        lastUpdated => 1249056084,
+    },
+
+    'Gradebook Report Template help' => {
+        message     => q|The template used to display the Gradebook Report|,
+        lastUpdated => 0,
+    },
+
+    'Survey Edit Template' => {
+        message     => q|Survey Edit Template|,
+        lastUpdated => 0,
+    },
+
+    'Survey Edit Template help' => {
+        message     => q|The template used to display the Survey Edit screen.|,
+        lastUpdated => 0,
+    },
+
+    'Allow back button' => {
+        message     => q|Allow back button|,
+        lastUpdated => 0,
+    },
+
+    'Allow back button help' => {
+        message     => q|Allow the user to navigate backwards in a Survey.|,
+        lastUpdated => 0,
+    },
+
     'Max user responses' => {
         message => q|Max user responses|,
         context => q|The maximum number of times a user may take this survey.|,
@@ -523,17 +671,6 @@ our $I18N = {
         lastUpdated => 0
     },
 
-    'Response Template' => {
-        message => q|Response Template|,
-        context => q|The template for displaying responses to the survey.|,
-        lastUpdated => 0
-    },
-
-    'Response Template help' => {
-        message => q|The template for displaying responses to the survey.|,
-        lastUpdated => 0
-    },
-
     'Edit Survey Template' => {
         message => q|Edit Survey Template|,
         context => q|The template for displaying the screen for editing the survey.|,
@@ -545,6 +682,18 @@ our $I18N = {
         lastUpdated => 0
     },
 
+    'Survey Summary Template' => {
+        message => q|Survey Summary Template|,
+        context => q|The template for displaying the summary page to users.|,
+        lastUpdated => 0
+    },
+
+    'Survey Summary Template help' => {
+        message => q|This is the template shown to users in quiz mode to summarize their results.|,
+        context => q|The template for displaying the summary page to users.|,
+        lastUpdated => 0
+    },
+
     'Take Survey Template' => {
         message => q|Take Survey Template|,
         context => q|The template for displaying the screen where a user takes the survey.|,
@@ -552,7 +701,7 @@ our $I18N = {
     },
 
     'Take Survey Template help' => {
-        message => q|The template for displaying the screen where a user takes the survey.|,
+        message => q|The template used to control the initial Take Survey screen, from which responses are dynamically loaded into.|,
         lastUpdated => 0
     },
 
@@ -563,7 +712,7 @@ our $I18N = {
     },
 
     'Questions Template help' => {
-        message => q|The template for rendering questions in the survey.|,
+        message => q|The template used to display individual questions, which are dynamically loaded into the Take Survey page.|,
         lastUpdated => 0
     },
 
@@ -574,7 +723,7 @@ our $I18N = {
     },
 
     'Section Edit Template help' => {
-        message => q|The template for adding or editing sections.|,
+        message => q|The template used to display the Section Edit dialog on the Edit Survey page.|,
         lastUpdated => 0
     },
 
@@ -585,7 +734,7 @@ our $I18N = {
     },
 
     'Question Edit Template help' => {
-        message => q|The template for adding or editing questions.|,
+        message => q|The template used to display the Question Edit dialog on the Edit Survey page.|,
         lastUpdated => 0
     },
 
@@ -596,7 +745,7 @@ our $I18N = {
     },
 
     'Answer Edit Template help' => {
-        message => q|The template for adding or editing answers.|,
+        message => q|The template used to display the Answer Edit dialog on the Edit Survey page.|,
         lastUpdated => 0
     },
 
@@ -775,6 +924,42 @@ directly inside the answer_loop for other types of questions.|,
         lastUpdated => 1149654771,
     },
 
+    response_feedback_url => {
+        message => q|The URL of the individual response feedback page.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    response_id  => {
+        message => q|The unique ID of the response.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    response_userId => {
+        message => q|The userId of the user that completed the response.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    response_ip => {
+        message => q|The IP Address of the user that completed the response.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    response_startDate => {
+        message => q|The Start Date of the response.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    response_endDate => {
+        message => q|The End Date of the response.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
     'survey template common vars title' => {
         message => q|Survey Template Common Vars|,
         context => q|The title of a template Help page.|,
@@ -787,38 +972,102 @@ directly inside the answer_loop for other types of questions.|,
         lastUpdated => 1078223096
     },
 
-    'lastResponseCompleted' => {
-        message => q|A boolean indicating wether the current user's last response was completed.|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
+    'response complete' => {
+        message => q|Survey Response completed|,
+        lastUpdated => 1242180657,
     },
 
-    'lastResponseTimedOut' => {
-        message => q|A boolean indicating wether the current user's last response timed out.|,
-        context => q|Description of a template variable for a template Help page.|,
+    'response complete help' => {
+        message => q|A boolean flag indicating whether the Survey Response completed|,
+        lastUpdated => 1242180657,
+    },
+
+    'responseId help' => {
+        message => q|The unique GUID for the response|,
+        lastUpdated => 1242180657,
+    },
+
+    'response restart' => {
+        message => q|Survey Response restarted|,
+        lastUpdated => 1242180657,
+    },
+
+    'response restart help' => {
+        message => q|A boolean flag indicating whether the Survey Response restarted|,
+        lastUpdated => 1242180657,
+    },
+
+    'response timeout' => {
+        message => q|Survey Response timed out|,
+        lastUpdated => 1242180657,
+    },
+
+    'response timeout help' => {
+        message => q|A boolean flag indicating whether the Survey Response timed out|,
+        lastUpdated => 1242180657,
+    },
+
+    'response timeout restart' => {
+        message => q|Survey Response restarted due to a timeout|,
+        lastUpdated => 1242180657,
+    },
+
+    'response timeout restart help' => {
+        message => q|A boolean flag indicating whether the Survey Response restarted as a result of a timeout|,
+        lastUpdated => 1242180657,
+    },
+
+    'response endDate help' => {
+        message => q|A localised date/time string indicating when the response ended|,
+        lastUpdated => 1242180657,
+    },
+
+    'survey feedback template variables title' => {
+        message => q|Survey Feedback Template Variables|,
+        lastUpdated => 1242256111,
+    },
+
+    'survey feedback template body' => {
+        message => q|All data tagged in survey expressions is also made available as template variables|,
+        lastUpdated => 1242180657,
+    },
+
+    'survey test results template title' => {
+        message => q|Survey Test Results Template Variables|,
+        lastUpdated => 1242256111,
+    },
+
+    'survey test results template body' => {
+        message => q|All TAP::Parser and TAP::Parser::Result fields are exposed as template variables|,
         lastUpdated => 0,
     },
 
     'maxResponsesSubmitted' => {
-        message => q|A boolean indicating wether the current user has reached the maximum number of responses.|,
+        message => q|A boolean indicating whether the current user has reached the maximum number of responses.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
     'user_canTakeSurvey' => {
-        message => q|A boolean indicating wether the current user can take the survey.|,
+        message => q|A boolean indicating whether the current user can take the survey.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
     'user_canViewReports' => {
-        message => q|A boolean indicating wether the current user can view the survey reports.|,
+        message => q|A boolean indicating whether the current user can view the survey reports.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 0,
+    },
+
+    'lastResponseFeedback help' => {
+        message => q|The templated response feedback text|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
     'user_canEditSurvey' => {
-        message => q|A boolean indicating wether the current user can edit the survey.|,
+        message => q|A boolean indicating whether the current user can edit the survey.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
@@ -860,9 +1109,27 @@ directly inside the answer_loop for other types of questions.|,
     },
 
     'templateId' => {
-        message => q|The ID of the template to show the Survey.|,
+        message => q|The ID of the template to show the front page of the Survey.|,
         context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 1168639537,
+        lastUpdated => 1236891448,
+    },
+
+    'gradebookTemplateId' => {
+        message => q|The ID of the template used to show the gradebook screen.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 1168643669,
+    },
+
+    'responseTemplateId' => {
+        message => q|The ID of the template used to show the Survey Response screen.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 1168643669,
+    },
+
+    'overviewTemplateId' => {
+        message => q|The ID of the template used to show the overview screen.|,
+        context => q|Description of a template variable for a template Help page.|,
+        lastUpdated => 1168643669,
     },
 
     'groupToTakeSurvey' => {
@@ -878,27 +1145,9 @@ directly inside the answer_loop for other types of questions.|,
     },
 
     'maxResponsesPerUser' => {
-        message => q|The number of times the user can attempt to get the correct answer on each question. The default is 1.|,
+        message => q|The number of times the user can attempt to get the correct answer on each question. 0 means unlimited. The default is 1.|,
         context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 1168643566,
-    },
-
-    'overviewTemplateId' => {
-        message => q|The ID of the template used to show the overview screen.|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 1168643669,
-    },
-
-    'gradebookTemplateId' => {
-        message => q|The ID of the template used to show the gradebook screen.|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 1168643669,
-    },
-
-    'responseTemplateId' => {
-        message => q|The ID of the template used to show the Survey Response screen.|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 1168643669,
+        lastUpdated => 1238131023,
     },
 
     'survey questions template title' => {
@@ -920,17 +1169,27 @@ directly inside the answer_loop for other types of questions.|,
     },
 
     'totalQuestions' => {
-        message => q|A boolean indicating wether the user should see the total number of answers and the number of questions that have already been answered.|,
+        message => q|A boolean indicating whether the user should see the total number of answers and the number of questions that have already been answered.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
     'showTimeLimit' => {
-        message => q|A boolean indicating wether the number of minutes until the survey times out should be displayed.|,
+        message => q|A boolean indicating whether the number of minutes until the survey times out should be displayed.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
+    'isLastPage' => {
+        message => q|A boolean indicating whether this is the last page of the survey.|,
+        context => q|Description of a template variable for a template Help page.|,
+    },
+
+    'allowBackBtn' => {
+        message => q|A boolean indicating whether the back button is allowed.|,
+        context => q|Description of a template variable for a template Help page.|,
+    },
+
     'minutesLeft' => {
         message => q|The number of minutes the user has left to finish the survey.|,
         context => q|Description of a template variable for a template Help page.|,
@@ -1150,7 +1409,7 @@ section/answer.|,
     },
 
     'randomizeAnswers' => {
-        message => q|A boolean indicating wether this question's answers should be randomized.|,
+        message => q|A boolean indicating whether this question's answers should be randomized.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
@@ -1198,7 +1457,7 @@ section/answer.|,
     },
 
     'textInButton' => {
-        message => q|A boolean indicating whether the buttons for answers to multiple choice questions should display the answer's text.|,
+        message => q|A boolean indicating whether the buttons for answers to multiple choice questions should display the answer's text inside or above.|,
         context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
@@ -1227,18 +1486,6 @@ section/answer.|,
         lastUpdated => 0,
     },
 
-    'min' => {
-        message => q|The min value of this answer for slider type questions.|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
-    },
-
-    'max' => {
-        message => q|The max value of this answer for slider type questions..|,
-        context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
-    },
-
     'step' => {
         message => q|The step value of this answer for slider type questions..|,
         context => q|Description of a template variable for a template Help page.|,
@@ -1246,21 +1493,31 @@ section/answer.|,
     },
 
     'recordedAnswer' => {
-        message => q|The value that gets recorded for this answer in the database.|,
+        message => q|The answer that gets recorded for this answer in the database.  This is relevant only for Multiple Choice questions, where the answer that is recorded may be different from what is what is displayed, e.g. 'Yes' could be recorded as '1' and 'No' as '0'.|,
         context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
+        lastUpdated => 1249057018,
     },
 
     'textCols' => {
-        message => q|The number of columns for textarea answers.|,
+        message => q|The number of columns for TextArea questions.|,
         context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
+        lastUpdated => 1241588599,
+    },
+
+    'textCols label' => {
+        message => q|TextArea Columns|,
+        lastUpdated => 1241588599
     },
 
     'textRows' => {
-        message => q|The number of rows for textarea answers.|,
+        message => q|The number of rows for TextArea questions.|,
         context => q|Description of a template variable for a template Help page.|,
-        lastUpdated => 0,
+        lastUpdated => 1241588599,
+    },
+
+    'textRows label' => {
+        message => q|TextArea Rows|,
+        lastUpdated => 1241588599
     },
 
     'answers' => {
@@ -1276,16 +1533,178 @@ section/answer.|,
     },
 
     'showProgress' => {
-        message => q|A boolean that is true if the asset has been configured to show how much progess the user has made in completing this Survey.|,
+        message => q|A boolean that is true if the asset has been configured to show how much progress the user has made in completing this Survey.|,
         context => q|Template variable doc.|,
+        lastUpdated => 1249057498,
+    },
+
+    'min' => {
+        message => q|The min value of this answer for slider type questions.|,
+        context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
     },
 
-   'restart message' =>{
-        message => q|The survey was restarted because the time limit for completing the survey was reached.|,
+    'max' => {
+        message => q|The max value of this answer for slider type questions..|,
+        context => q|Description of a template variable for a template Help page.|,
         lastUpdated => 0,
-        context => q|The message shown to the user taking the survey when the survey is restarted after reaching the time limit for completing the survey. This message is in the 'take survey' template.|,
     },
+
+    'year' => {
+        message => q|Year (YYYY):|,
+        context => q|Sub-label for "Year Month" question type|,
+        lastUpdated => 0,
+    },
+
+    'month' => {
+        message => q|Month:|,
+        context => q|Sub-label for "Year Month" question type|,
+        lastUpdated => 0,
+    },
+
+    'back' => {
+        message => q|Back|,
+        context => q|Back button label on Take Survey page|,
+        lastUpdated => 0,
+    },
+
+    'continue' => {
+        message => q|Continue|,
+        context => q|Continue button label on Take Survey page|,
+        lastUpdated => 0,
+    },
+
+    'finish' => {
+        message => q|Finish|,
+        context => q|Finish button label on Take Survey page|,
+        lastUpdated => 0,
+    },
+
+    'add a test' => {
+        message => q{Add a test},
+        lastUpdated => 0,
+    },
+
+    'confirm delete test' => {
+        message => q{Are you sure you want to delete this test?},
+        lastUpdated => 0,
+    },
+
+    'test suite' => {
+        message => q{Test Suite},
+        lastUpdated => 0,
+    },
+
+    'edit test' => {
+        message => q{Edit Test},
+        lastUpdated => 0,
+    },
+
+    'run test' => {
+        message => q{Run Test},
+        lastUpdated => 0,
+    },
+
+    'test name' => {
+        message => q{Test Name},
+        lastUpdated => 0,
+    },
+
+    'tests run' => {
+        message => q{Tests Run},
+        lastUpdated => 0,
+    },
+
+    'test name help' => {
+        message => q{A descriptive name for this test},
+        lastUpdated => 0,
+    },
+
+    'test spec' => {
+        message => q{Test Spec},
+        lastUpdated => 0,
+    },
+
+    'test spec help' => {
+        message => q{The JSON-encoded specification for your test(s)},
+        lastUpdated => 0,
+    },
+
+    'run all tests' => {
+        message => q{Run All Tests},
+        lastUpdated => 0,
+    },
+
+    'pass' => {
+        message => q{Pass},
+        lastUpdated => 0,
+    },
+
+    'fail' => {
+        message => q{Fail},
+        lastUpdated => 0,
+    },
+
+    'test results template' => {
+        message => q{Test Results Template},
+        lastUpdated => 0,
+    },
+
+    'test results template help' => {
+        message => q{Template used to display individual test and aggregate test results},
+        lastUpdated => 0,
+    },
+
+    'test results' => {
+        message => q{Test Results},
+        lastUpdated => 0,
+    },
+
+    'test result' => {
+        message => q{Test Result},
+        lastUpdated => 0,
+    },
+
+    'details' => {
+        message => q{Details},
+        lastUpdated => 0,
+    },
+
+    'tests passed' => {
+        message => q{Tests Passed},
+        lastUpdated => 0,
+    },
+
+    'tests failed' => {
+        message => q{Tests Failed},
+        lastUpdated => 0,
+    },
+
+    'start date' => {
+        message => q{Start Date},
+        lastUpdated => 0,
+    },
+
+    'end date' => {
+        message => q{End Date},
+        lastUpdated => 0,
+    },
+
+    'Survey Objects' => {
+        message => q{Survey Objects},
+        lastUpdated => 0,
+    },
+
+    'Make Default Type' => {
+        message => q{Make Default Type},
+        lastUpdated => 0,
+    },
+
+    'Remove Default Type' => {
+        message => q{Remove Default Type},
+        lastUpdated => 0,
+    },
+
 };
 
 1;
