@@ -74,6 +74,11 @@ our $I18N = {
 		lastUpdated => 1078852969
 	},
 
+	'deactivate account template' => {
+		message => q|Deactivate Account Template|,
+		lastUpdated => 1269278436,
+	},
+
 	'login template' => {
 		message => q|Login Template|,
 		lastUpdated => 1078852969
@@ -84,6 +89,11 @@ our $I18N = {
 		lastUpdated => 1184793098
 	},
 
+	'deactivate account template title' => {
+		message => q|LDAP Authentication Deactivate Account Template Variables|,
+		lastUpdated => 1269279436,
+	},
+
 	'11' => {
 		message => q|No connect DN specified for this user|,
 		lastUpdated => 1071848383
@@ -159,6 +169,12 @@ our $I18N = {
 		lastUpdated => 1031514049,
 	},
 
+	'LDAP User DN' => {
+		message => q|LDAP User DN|,
+		lastUpdated => 1265671176,
+        context => q|The actual DN for the user to use when logging in.|,
+	},
+
 	'connect_dn_help' => {
 		message => q|The distinguished name used to make an LDAP connection.  Used to be called Connect DN.|,
 		lastUpdated => 1249688660,
@@ -616,6 +632,11 @@ and should be entered as such.</p>|,
                 lastUpdated => 1120164594,
         },
 
+        'deactivate account template description' => {
+                message => q|Template to be used to show the form for deactivating an account.|,
+                lastUpdated => 1269278461,
+        },
+
         'login template description' => {
                 message => q|Template used to display login information to the user as an operation, as opposed to inside of a page via a macro.|,
                 lastUpdated => 1165512102,
