@@ -7,13 +7,18 @@ our $I18N = {
                 lastUpdated => 0,
                 context => q|Default Cash payment gateway label|
         },
-
+	
 	'module name' => {
 		message => q|Cash|,
 		lastUpdated => 0,
 		context => q|The displayed name of the payment module.|
 	},
 
+	'no description' => {
+		message => q|No description|,
+		lastUpdated => 0,
+		context => q|The default description of purchase of users.|
+	},
 	'cash' => {
 		message => q|Cash|,
 		lastUpdated => 0,
@@ -42,6 +47,30 @@ our $I18N = {
 		message => q|When set to 'yes', the transaction is completed when the user submits payment details.  When set to 'no', the transaction is set to pending and must be manually set to complete.  This may be useful if you wish to allow site visitors to select the Cash Payment method, but would like to wait for payment to clear before completing the transaction.|,
 		lastUpdated => 0,
 	},
+
+    'summary template' => {
+        message => q|Summary Template|,
+        lastUpdated => 0,
+        context => q|Form label in the configuration form of the Cash module.|
+    },
+    'summary template help' => {
+        message => q|Pick a template to display the screen where the user confirms the cart summary info and agrees to pay.|,
+        lastUpdated => 0,
+        context => q|Hover help for the summary template field in the configuration form of the Cash module.|
+    },
+ 
+	'Pay' => {
+		message => q|Pay|,
+		lastUpdated => 0,
+		context => q|Button label|
+	},
+
+	'cart summary template' => {
+		message => q|Cash Payment Method Cart Summary Template|,
+		lastUpdated => 0,
+		context => q||,
+	},
+
 };
 
 1;
