@@ -43,7 +43,7 @@ our $I18N = {
         context     => q{The name of the payment driver},
     },
     'password' => { 
-        message     => q{Password},
+        message     => q{API Password},
         lastUpdated => 1247254156,
     },
     'password help' => { 
@@ -88,7 +88,7 @@ our $I18N = {
         lastUpdated => 1247253981,
     },
     'user' => { 
-        message     => q{Username},
+        message     => q{API Username},
         lastUpdated => 1247254097,
     },
     'user help' => { 
@@ -104,20 +104,9 @@ our $I18N = {
     'summary template help' => {
         message => q|Pick a template to display the screen where the user confirms the cart summary info and agrees to pay.|,
         lastUpdated => 0,
-        context => q|Hover help for the summary template field in the configuration form of the Cash module.|
+        context => q|Hover help for the summary template field in the configuration form.|
     },
  
-	'password' => {
-		message => q|Password|,
-		lastUpdated => 0,
-		context => q|Form label in the configuration form of the iTransact module.|
-	},
-	'password help' => {
-		message => q|The password for your ITransact account.|,
-		lastUpdated => 0,
-		context => q|Hover help for the password field in the configuration form of the iTransact module.|
-	},
-
 	'Pay' => {
 		message => q|Pay|,
 		lastUpdated => 0,
