@@ -12,56 +12,6 @@ our $I18N = {
         lastUpdated => 0,
         context => q|The name of the ITransact plugin|,
     },
-	'label' => {
-        message => q|Credit Card|,
-        lastUpdated => 0,
-        context => q|Default ITransact payment gateway label|
-    },
-    'phone' => {
-        message => q|Telephone Number|,
-        lastUpdated => 0,
-        context => q|Form label in the checkout form of the iTransact module.|
-    },
-    'country' => {
-        message => q|Country|,
-        lastUpdated => 0,
-        context => q|Form label in the checkout form of the iTransact module.|
-    },
-	'firstName' => {
-		message => q|First name|,
-		lastUpdated => 0,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'lastName' => {
-		message => q|Last name|,
-		lastUpdated => 0,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'address' => {
-		message => q|Address|,
-		lastUpdated => 1101772170,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'city' => {
-		message => q|City|,
-		lastUpdated => 1101772171,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'state' => {
-		message => q|State|,
-		lastUpdated => 1101772173,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'zipcode' => {
-		message => q|Zipcode|,
-		lastUpdated => 1101772174,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
-	'email' => {
-		message => q|Email|,
-		lastUpdated => 1101772176,
-		context => q|Form label in the checkout form of the iTransact module.|
-	},
 	'cardNumber' => {
 		message => q|Credit card number|,
 		lastUpdated => 1101772177,
@@ -124,7 +74,7 @@ our $I18N = {
 	},
 
 	'edit credentials template' => {
-		message => q|Edit Credentials Template|,
+		message => q|ITransact Edit Credentials Template|,
 		lastUpdated => 0,
 		context => q|Title of the help page.|
 	},
@@ -152,18 +102,6 @@ our $I18N = {
 		context => q|Template variable help.|
 	},
 
-   	'addressField help' => {
-		message => q|A single text field for the user to enter in their street address.|,
-		lastUpdated => 0,
-		context => q|Template variable help.|
-	},
-
-   	'emailField help' => {
-		message => q|A single text field for the user to enter in their email address.|,
-		lastUpdated => 1231192368,
-		context => q|Template variable help.|
-	},
-
    	'cardNumberField help' => {
 		message => q|A single text field for the user to enter in their credit card number.|,
 		lastUpdated => 0,
@@ -252,11 +190,6 @@ our $I18N = {
 		lastUpdated => 0,
 		context => q|An error indicating that an invalid city has been entered.|
 	},
-	'invalid state' => {
-		message => q|You have to enter a state or province.  If your address does not have one, please enter in the city again.|,
-		lastUpdated => 0,
-		context => q|An error indicating that an invalid city has been entered.|
-	},
 	'invalid zip' => {
 		message => q|You have to enter a valid zipcode.|,
 		lastUpdated => 0,
