@@ -26,8 +26,8 @@ our $I18N = {
     'message' => 'Weitere Tabelle hinzufügen'
   },
   'add thing label' => {
-    'lastUpdated' => '1227001889',
-    'message' => 'Tabelle hinzufügen'
+    'lastUpdated' => '1316500636',
+    'message' => 'Tabelleneintrag hinzufügen'
   },
   'addThing_url' => {
     'lastUpdated' => '1227002010',
@@ -61,6 +61,10 @@ our $I18N = {
     'lastUpdated' => '1244363512',
     'message' => 'Da alle Benutzer dieses Asset in gleicher Form sehen, kann es, um die Performance zu erhöhen, für längere Zeit ins Cache aufgenommen werden. Wie lange soll es aufgenommen werden?'
   },
+  'callerAssetId' => {
+    'lastUpdated' => '1309239575',
+    'message' => 'Wenn in www_viewThingData übergeben, wird die assetId des caller assets bereitgestellt. Wird von RenderThingMacro genutzt. Näheres siehe POD.'
+  },
   'canEditThings' => {
     'lastUpdated' => '1241126984',
     'message' => '"wahr" wenn der aktuelle Benutzer die Tabellen in diesem Asset sehen kann.'
@@ -82,10 +86,12 @@ our $I18N = {
     'message' => 'Standardtabelle'
   },
   'default value description' => {
-    'lastUpdated' => '1236680887',
+    'lastUpdated' => '1316522662',
     'message' => 'Geben Sie ggf. einen Standardwert für dieses Feld ein.
 Wenn Sie einen Hash mit möglichen Werten definiert haben, dann soll der Standardwert ein Schlüssel dieses Hashes sein und kein Wert.
-Bei "Ja/Nein" Feldern, geben Sie "yes" für "Ja" und "no" für "Nein" ein.'
+Bei "Ja/Nein" Feldern, geben Sie "yes" für "Ja" und "no" für "Nein" ein.
+Für Datum-Zeit-Felder geben Sie das Datum im Epoch-Date-format oder in ISO 9601 mit optionaler Zeitangabe: YYYY-MM-DD HH:MM:SS an.
+'
   },
   'default value label' => {
     'lastUpdated' => '1227001811',
@@ -747,6 +753,18 @@ Wenn Sie "verborgen" oder "sichtbar" wählen, geben Sie bitte auch einen Standar
     'lastUpdated' => '1240471739',
     'message' => 'Tabellenvorlage'
   },
+  'unique description' => {
+    'lastUpdated' => '1308051838',
+    'message' => 'Ist dies ein eindeutiges Feld? In einfachen Worten: Werte in eindeutigen Feldern dürfen keine Duplikate in anderen Zeilen haben.'
+  },
+  'unique label' => {
+    'lastUpdated' => '1308051845',
+    'message' => 'Eindeutig'
+  },
+  'variables by label' => {
+    'lastUpdated' => '1304526771',
+    'message' => 'In Ergänzung zum filed_loop können Felder auch direkt über ihr Label angesprochen werden. Prüfen Sie bitte in der Dokumentation des verwendeten Template-Plugins, wie Sonderzeichen, z.B. Leerzeichen oder Anführungszeichen, behandelt werden müssen.'
+  },
   'vertical description' => {
     'lastUpdated' => '1227000728',
     'message' => 'Diese Eigenschaft bestimmt ob Knöpfe horizontal oder vertikal angezeigt werden.'
