@@ -94,8 +94,8 @@ our $I18N = {
     'message' => 'Passwortwiederherstellung erlauben?'
   },
   7 => {
-    'lastUpdated' => '1153201835',
-    'message' => 'Passwörter müssen eine Mindestlänge haben von <br />'
+    'lastUpdated' => '1317202144',
+    'message' => 'Passwörter müssen eine Mindestlänge haben von &nbsp;'
   },
   8 => {
     'lastUpdated' => '1153201846',
@@ -292,8 +292,8 @@ Danach können Sie sich mit Ihrer Kennung und dem Passwort anmelden.
     'message' => 'Geben Sie ein neues Kennwort auf Ihren Account unten ein.'
   },
   'email recover password finish message' => {
-    'lastUpdated' => '1287563192',
-    'message' => 'Eine E-Mail mit einer Anleitung zur Änderung des Passwort wurde verschickt.'
+    'lastUpdated' => '1362267659',
+    'message' => 'Eine E-Mail mit einer Anleitung zur Änderung des Passworts wurde verschickt.'
   },
   'email recover password finish message1' => {
     'lastUpdated' => '1192977827',
@@ -304,8 +304,8 @@ Danach können Sie sich mit Ihrer Kennung und dem Passwort anmelden.
     'message' => 'Mit Instruktionen, um Ihr Passwort zurück zu setzen.'
   },
   'email recover password start message' => {
-    'lastUpdated' => '1192977996',
-    'message' => 'Geben Sie entweder Ihre E-Mail-Adresse oder Ihre Anmeldung unten ein, um das Passwort zurücksetzen zu können.'
+    'lastUpdated' => '1316512933',
+    'message' => 'Geben Sie entweder Ihre E-Mail-Adresse oder Ihre Login-Kennung ein, um ein neues Passwort zu erhalten.'
   },
   'email validation confirmed' => {
     'lastUpdated' => '1252480610',
@@ -485,8 +485,8 @@ Sie können sich jetzt mit Ihrer Kennung und Ihrem Passwort anmelden.'
     'message' => 'Wählen Sie die Vorlage für die Seite aus, die dem Benutzer angezeigt wird, auf der er ein verlorendes Passwort wiederherstellen kann.'
   },
   'recover password banner' => {
-    'lastUpdated' => '1225317250',
-    'message' => 'Wiederherstellung Passwort'
+    'lastUpdated' => '1316512776',
+    'message' => 'Neues Passwort'
   },
   'recover password email text1' => {
     'lastUpdated' => '1225317402',
