@@ -23,7 +23,7 @@ BEGIN {
 
 $|++;    # disable output buffering
 
-our ( $configFile, $help, $man, $fix, $delete, $no_progress );
+our ( $configFile, $help, $man, $fix, $delete, $no_progress, $op_assetId );
 use Pod::Usage;
 use Getopt::Long;
 use WebGUI::Session;
@@ -36,6 +36,7 @@ GetOptions(
     'fix'          => \$fix,
     'delete'       => \$delete,
     'noProgress'   => \$no_progress,
+    'assetId=s'    => \$op_assetId,
 );
 
 pod2usage( verbose => 1 ) if $help;
@@ -62,18 +63,37 @@ sub progress {
     printf ' (%d/%d)', $current, $total;
 }
 
-my $totalAsset      = $session->db->quickScalar('SELECT COUNT(*) FROM asset');
-my $totalAssetData  = $session->db->quickScalar('SELECT COUNT( DISTINCT( assetId ) ) FROM assetData' );
-my $total   = $totalAsset >= $totalAssetData ? $totalAsset : $totalAssetData;
+## SQL statements
+
+my $total_asset_sql     = 'SELECT COUNT(*) FROM asset ';
+my $total_assetdata_sql = 'SELECT COUNT( DISTINCT( assetId ) ) FROM assetData ';
+my $count_shortcut_sql  = q!select count(*) from asset where className='WebGUI::Asset::Shortcut' !;
+my $count_files_sql     = q!select count(*) from asset where className like 'WebGUI::Asset::File%' !;
 
 # Order by lineage to put corrupt parents before corrupt children
 # Join assetData to get all asset and assetData
-my $sql   = "SELECT * FROM asset LEFT JOIN assetData USING ( assetId ) GROUP BY assetId ORDER BY lineage ASC";
-my $sth   = $session->db->read($sql);
+my $iterator_sql   = "SELECT assetId, className, revisionDate, parentId FROM asset LEFT JOIN assetData USING ( assetId ) ";
+my $sql_args = [];
+if ($op_assetId) {
+    my $asset_selector    = 'where assetId = ? ';
+    $iterator_sql        .= $asset_selector;
+    $total_asset_sql     .= $asset_selector;
+    $total_assetdata_sql .= $asset_selector;
+    $count_shortcut_sql  .= ' AND assetId = ? ';
+    $count_files_sql      .= ' AND assetId = ? ';
+    push @{ $sql_args }, $op_assetId;
+}
+$iterator_sql .= "GROUP BY assetId ORDER BY lineage ASC";
+my $sth   = $session->db->read($iterator_sql, $sql_args);
+
+my $totalAsset      = $session->db->quickScalar($total_asset_sql, $sql_args);
+my $totalAssetData  = $session->db->quickScalar($total_assetdata_sql, $sql_args);
+my $total   = $totalAsset >= $totalAssetData ? $totalAsset : $totalAssetData;
 
 ##Guarantee that we get the most recent revisionDate
 my $max_revision  = $session->db->prepare('select max(revisionDate) from assetData where assetId=?');
 
+print "Checking all assets\n";
 my $count = 1;
 my %classTables;            # Cache definition lookups
 while ( my %row = $sth->hash ) {
@@ -111,13 +131,13 @@ while ( my %row = $sth->hash ) {
 
             my $asset   = WebGUI::Asset->newByDynamicClass( $session, $row{assetId} );
             # Make sure we have a valid parent
-            unless ( $asset && WebGUI::Asset->newByDynamicClass( $session, $row{parentId} ) ) {
-                $asset->setParent( WebGUI::Asset->getImportNode( $session ) );
-                print "\tNOTE: Invalid parent. Asset moved to Import Node\n";
-            }
             if (!$asset) {
                 print "\tWARNING.  Asset is still broken.\n";
             }
+            elsif (! WebGUI::Asset->newByDynamicClass( $session, $row{parentId} )) {
+                $asset->setParent( WebGUI::Asset->getImportNode( $session ) );
+                print "\tNOTE: Invalid parent. Asset moved to Import Node\n";
+            }
 
         } ## end if ($fix)
         elsif ($delete) {
@@ -204,6 +224,87 @@ while ( my %row = $sth->hash ) {
 } ## end while ( my %row = $sth->hash)
 $sth->finish;
 $max_revision->finish;
+print "\n";
+
+my $shortcuts = $session->db->quickScalar($count_shortcut_sql, $sql_args);
+if ($shortcuts) {
+    print "Checking for broken shortcuts\n";
+    use WebGUI::Asset::Shortcut;
+    my $get_shortcut = WebGUI::Asset::Shortcut->getIsa($session, 0, {returnAll => 1});
+    $count = 0;
+    SHORTCUT: while (1) {
+        my $shortcut = eval { $get_shortcut->() };
+        if ( $@ || Exception::Class->caught() ) {
+            ##Do nothing, since it would have been caught above
+            printf "\r%-68s", "No shortcut to check";
+        }
+        elsif (!$shortcut) {
+            last SHORTCUT
+        }
+        else {
+            my $linked_asset = eval { WebGUI::Asset->newPending($session, $shortcut->get('shortcutToAssetId')); };
+            if ( $@ || Exception::Class->caught() || ! $linked_asset ) {
+                printf "\r%-68s", "-- Broken shortcut: ".$shortcut->getId.' pointing to '.$shortcut->get('shortcutToAssetId');
+                if ($delete) {
+                    my $success = $shortcut->purge;
+                    if ($success) {
+                        print "Purged shortcut";
+                    }
+                    else {
+                        print "Could not purge shortcut";
+                    }
+                }
+                print "\n";
+            }
+        }
+        progress( $shortcuts, $count++ ) unless $no_progress;
+    }
+    progress( $shortcuts, $count ) unless $no_progress;
+}
+
+print "\n";
+
+my $file_assets = $session->db->quickScalar($count_files_sql, $sql_args);
+if ($file_assets) {
+    print "Checking for broken File Assets\n";
+    use WebGUI::Asset::File;
+    my $get_asset = WebGUI::Asset::File->getIsa($session, 0, {returnAll => 1});
+    $count = 0;
+    FILE_ASSET: while (1) {
+        my $file_asset = eval { $get_asset->() };
+        if ( $@ || Exception::Class->caught() ) {
+            ##Do nothing, since it would have been caught above
+            printf "\r%-68s\n", "No asset to check";
+        }
+        elsif (!$file_asset) {
+            last FILE_ASSET
+        }
+        else {
+            my $storage = $file_asset->getStorageLocation;
+            if (! $storage) {
+                printf "\r%-s\n", "-- No storage location: ".$file_asset->getId." storageId: ".$file_asset->get('storageId');
+            }
+            else {
+                my $file = $storage->getPath($file_asset->get('filename'));
+                if (! -e $file) {
+                    printf "\r%-s", "-- Broken file asset: ".$file_asset->getId." file does not exist: $file";
+                    if ($delete) {
+                        my $success = $file_asset->purge;
+                        if ($success) {
+                            print "Purged File Asset";
+                        }
+                        else {
+                            print "Could not purge File Asset";
+                        }
+                    }
+                    print "\n";
+                }
+            }
+        }
+        progress( $file_assets, $count++ ) unless $no_progress;
+    }
+    progress( $file_assets, $count ) unless $no_progress;
+}
 
 finish($session);
 print "\n";
@@ -261,7 +362,20 @@ findBrokenAssets.pl -- Find and fix broken assets
 =head1 DESCRIPTION
 
 This utility will find any broken assets that cannot be instantiated and are 
-causing undesired operation of your website.
+causing undesired operation of your website.  It also checks for these kinds of
+semi-working assets and reports them:
+
+=over 4
+
+=item *
+
+Shortcuts pointing to assets that don't exist.
+
+=item *
+
+File assets that have lost their files in the uploads area.
+
+=back
 
 It can also automatically delete them or fix them so you can restore missing data.
 
@@ -283,7 +397,11 @@ Delete any corrupted assets.
 
 =item B<--fix>
 
-Try to fix any corrupted assets.
+Try to fix any corrupted assets.  The broken Shortcuts and File Assets cannot be fixed.
+
+=item B<--assetId=s>
+
+Limit the search for all broken assets to one assetId.
 
 =item B<--help>
 
