@@ -10,9 +10,17 @@
 #  http://www.plainblack.com                     info@plainblack.com
 # -------------------------------------------------------------------
 
-$|=1;
-use lib '../lib';
 use strict;
+use File::Basename ();
+use File::Spec;
+
+my $webguiRoot;
+BEGIN {
+    $webguiRoot = File::Spec->rel2abs(File::Spec->catdir(File::Basename::dirname(__FILE__), File::Spec->updir));
+    unshift @INC, File::Spec->catdir($webguiRoot, 'lib');
+}
+
+$|=1;
 use Carp qw( carp croak );
 use File::Find;
 use Getopt::Long;
