@@ -42,6 +42,8 @@ pod2usage() unless (defined($configFile) && $configFile ne '');
 
 print "Starting..." unless ($quiet);
 my $session = WebGUI::Session->open($webguiRoot,$configFile);
+# We might take a while, reconnect if we get disconnected for inactivity
+$session->db->dbh->{mysql_auto_reconnect} = 1;
 print "OK\n" unless ($quiet);
 
 print "Looking for descendant replationships...\n" unless ($quiet);
