@@ -61,6 +61,7 @@ if ($] >= 5.008009) {
 ##Doing this as a global is not nice, but it works
 my $missingModule = 0;
 
+checkModule("String::Random",               0.22         );  # used by the WRE
 checkModule("LWP",                          5.833        );
 checkModule("HTML::Form",                   5.800,     2 );
 checkModule("Net::DNS",                     0.66,        );
@@ -133,7 +134,6 @@ checkModule("File::Path",                   "2.07"       );
 checkModule("Module::Find",                 "0.06"       );
 checkModule("Class::C3",                    "0.21"       );
 checkModule("Params::Validate",             "0.91"       );
-checkModule("Clone",                        "0.31"       );
 checkModule('JavaScript::Packer',           '1.002'      );
 checkModule('CSS::Packer',                  '1.000'      );
 checkModule('HTML::Packer',                 "1.000"      );
@@ -162,6 +162,7 @@ checkModule('Kwargs',                                    );
 checkModule('Data::ICal',                   '0.16'       );
 checkModule('common::sense',                '3.2'        );
 checkModule('Geo::Coder::Googlev3',         '0.07'       );
+checkModule('Storable',                     '2.00'       );
 
 failAndExit("Required modules are missing, running no more checks.") if $missingModule;
 
